#include <PCM.h>
#include "pitches.h"
#include <PS2X_lib.h>  //for v1.6

/******************************************************************
 * set pins connected to PS2 controller:
 *   - 1e column: original 
 *   - 2e colmun: Stef?
 * replace pin numbers by the ones you use
 ******************************************************************/
#define PS2_DAT        13  //14    
#define PS2_CMD        11  //15
#define PS2_SEL        10  //16
#define PS2_CLK        12  //17

/******************************************************************
 * select modes of PS2 controller:
 *   - pressures = analog reading of push-butttons 
 *   - rumble    = motor rumbling
 * uncomment 1 of the lines for each mode selection
 ******************************************************************/
#define pressures   true
//#define pressures   false
//#define rumble      true
#define rumble      false

PS2X ps2x; // create PS2 Controller Class

//right now, the library does NOT support hot pluggable controllers, meaning 
//you must always either restart your Arduino after you connect the controller, 
//or call config_gamepad(pins) again after connecting the controller.

int error = 0;
byte type = 0;
byte vibrate = 0;

const int tonePin = 6;

int melody[] = {
//  NOTE_C4, NOTE_G3, NOTE_G3, NOTE_A3, NOTE_G3,0, NOTE_B3, NOTE_C4};
    NOTE_B4, NOTE_A3, NOTE_A3, NOTE_D4, NOTE_A3, 0, NOTE_FS4, NOTE_B4};

// note durations: 4 = quarter note, 8 = eighth note, etc.:
int noteDurations[] = {
  4, 8, 8, 4,4,4,4,4 };

void setup(){

  Serial.begin(57600);

  delay(3000);  //added delay to give wireless ps2 module some time to startup, before configuring it

  //CHANGES for v1.6 HERE!!! **************PAY ATTENTION*************

  //setup pins and setMtings: GamePad(clock, command, attention, data, Pressures?, Rumble?) check for error
  error = ps2x.config_gamepad(PS2_CLK, PS2_CMD, PS2_SEL, PS2_DAT, pressures, rumble);

  if(error == 0){
    Serial.print("Found Controller, configured successful ");
    Serial.print("pressures = ");
    if (pressures)
      Serial.println("true ");
    else
      Serial.println("false");
    Serial.print("rumble = ");
    if (rumble)
      Serial.println("true)");
    else
      Serial.println("false");
    Serial.println("Try out all the buttons, X will vibrate the controller, faster as you press harder;");
    Serial.println("holding L1 or R1 will print out the analog stick values.");
    Serial.println("Note: Go to www.billporter.info for updates and to report bugs.");
  }  
  else if(error == 1)
    Serial.println("No controller found, check wiring, see readme.txt to enable debug. visit www.billporter.info for troubleshooting tips");

  else if(error == 2)
    Serial.println("Controller found but not accepting commands. see readme.txt to enable debug. Visit www.billporter.info for troubleshooting tips");

  else if(error == 3)
    Serial.println("Controller refusing to enter Pressures mode, may not support it. ");

  //  Serial.print(ps2x.Analog(1), HEX);

  type = ps2x.readType(); 
  switch(type) {
  case 0:
    Serial.print("Unknown Controller type found ");
    break;
  case 1:
    Serial.print("DualShock Controller found ");
    break;
  case 2:
    Serial.print("GuitarHero Controller found ");
    break;
  case 3:
    Serial.print("Wireless Sony DualShock Controller found ");
    break;
  }
}


int toneTime = 0;

void loop() {
  /* You must Read Gamepad to get new values and set vibration values
   ps2x.read_gamepad(small motor on/off, larger motor strenght from 0-255)
   if you don't enable the rumble, use ps2x.read_gamepad(); with no values
   You should call this at least once a second
   */
//  if(error == 1) //skip loop if no controller found
//    return; 
//
//  if(type != 2) // Guitar Hero  
//  { //DualShock Controller
    ps2x.read_gamepad(); //read controller and set large motor to spin at 'vibrate' speed

    if (ps2x.NewButtonState())
      if(ps2x.Button(PSB_START))      
      {
        //  // iterate over the notes of the melody:
        for (int thisNote = 0; thisNote < 8; thisNote++) {

          // to calculate the note duration, take one second 
          // divided by the note type.
          //e.g. quarter note = 1000 / 4, eighth note = 1000/8, etc.
          int noteDuration = 1000/noteDurations[thisNote];
          tone(tonePin, melody[thisNote],noteDuration);

          // to distinguish the notes, set a minimum time between them.
          // the note's duration + 30% seems to work well:
          int pauseBetweenNotes = noteDuration * 1.30;
          delay(pauseBetweenNotes);
          // stop the tone playing:
          noTone(tonePin);
        }
        
        delay (500);
      }

    //    if(ps2x.Button(PSB_SELECT))
    //      Serial.println(ps2x.Analog(PSAB_PAD_RIGHT), DEC);
    //    vibrate = ps2x.Analog(PSAB_CROSS);  //this will set the large motor vibrate speed based on how hard you press the blue (X) button
    //    if (ps2x.NewButtonState()) {        //will be TRUE if any button changes state (on to off, or off to on)
//    if(ps2x.ButtonPressed(PSB_CROSS)) {              //will be TRUE if button was JUST pressed OR released
//    if(ps2x.ButtonReleased(PSB_SQUARE))              //will be TRUE if button was JUST released


//    char pss_lx = ps2x.Analog(PSS_LX);
//    char pss_rx = ps2x.Analog(PSS_RX);
    
    toneTime = 250;
    if(ps2x.Button(PSB_L1) || ps2x.Button(PSB_R1))
    {
      toneTime = 125;
      if(ps2x.Button(PSB_L1) && ps2x.Button(PSB_R1))
        toneTime = 64;
    }
//    if ( (ps2x.Button(PSB_L1) && ps2x.Button(PSB_R1)) && (ps2x.Button(PSB_L2) || ps2x.Button(PSB_R2)) )
//      toneTime = 125;
//    if ( (ps2x.Button(PSB_L1) && ps2x.Button(PSB_R1)) && (ps2x.Button(PSB_L2) && ps2x.Button(PSB_R2)) )
//      toneTime = 64;
//    toneTime *= 1.2;
    
    int dNote = map( ps2x.Analog(PSS_LX) + ps2x.Analog(PSS_RX), 0, 510, -6, 6);

    if(ps2x.Button(PSB_CROSS)) {  
      tone(tonePin, NOTE_B3 + dNote, toneTime);
    } 
    else
    if(ps2x.Button(PSB_TRIANGLE)){   
      tone(tonePin, NOTE_B4 + dNote, toneTime);
    }   
    else
    if(ps2x.Button(PSB_PAD_DOWN)){
      tone(tonePin, NOTE_A3 + dNote, toneTime);
    }    
    else
    if(ps2x.Button(PSB_PAD_LEFT)) { 
      tone(tonePin, NOTE_D4 + dNote, toneTime);
    }
    else
    if(ps2x.Button(PSB_PAD_RIGHT)){
      tone(tonePin, NOTE_E4 + dNote, toneTime);
    }
    else
    if(ps2x.Button(PSB_SQUARE))  {  
      tone(tonePin, NOTE_FS4 + dNote, toneTime);
    }
    else
    if(ps2x.Button(PSB_CIRCLE))  {
      tone(tonePin, NOTE_A4 + dNote, toneTime);
    }
    else    
    if(ps2x.Button(PSB_PAD_UP)){
      noTone(tonePin);
    }


  //  if(ps2x.Button(PSB_L2))
  //   tone(6, (10+pss_lx)*(10+pss_rx) / 40);
  //startPlayback(&pss_lx, sizeof(&pss_lx));
  



//  delay(toneTime);  
//  noTone(tonePin);
}

